km3pipe.dataclasses.Hit
=======================

.. currentmodule:: km3pipe.dataclasses

.. autoclass:: Hit

   
   .. automethod:: __init__

   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Hit.channel_id
      ~Hit.dir_x
      ~Hit.dir_y
      ~Hit.dir_z
      ~Hit.dom_id
      ~Hit.id
      ~Hit.pmt_id
      ~Hit.pos_x
      ~Hit.pos_y
      ~Hit.pos_z
      ~Hit.t0
      ~Hit.time
      ~Hit.tot
      ~Hit.triggered
   
   